@@ -72,7 +72,7 @@ class TMotorManager():
         self._times_past_current_limit = 0
         self._times_past_velocity_limit = 0
         self._angle_threshold = MIT_Params[self.type]['P_max'] - 2.0 # radians, only really matters if the motor's going super fast
-        self._current_threshold = MIT_Params[self.type]['T_max']/(MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor']/MIT_Params[self.type]['Current_Factor']) - 4.0 # A, only really matters if the current changes quick
+        self._current_threshold = self.TMotor_current_to_qaxis_current(MIT_Params[self.type]['T_max']) - 4.0 # A, only really matters if the current changes quick
         self._velocity_threshold = MIT_Params[self.type]['V_max'] - 2.0 # radians, only really matters if the motor's going super fast
         self._old_pos = None
         self._old_curr = 0.0
@@ -136,6 +136,13 @@ class TMotorManager():
         if not (etype is None):
             traceback.print_exception(etype, value, tb)
 
+    def TMotor_current_to_qaxis_current(self, iTM):
+        return -MIT_Params[self.type]['Current_Factor']*iTM/(MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor'])
+    
+    def qaxis_current_to_TMotor_current(self, iq):
+        return iq*(MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor'])/MIT_Params[self.type]['Current_Factor']
+
+
     # this method is called by the handler every time a message is recieved on the bus
     # from this motor, to store the most recent state information for later
     def _update_state_async(self, MIT_state):
@@ -158,7 +165,8 @@ class TMotorManager():
         acceleration = (MIT_state.velocity - self._motor_state_async.velocity)/dt
 
         # The "Current" supplied by the controller is actually current*Kt, which approximates torque.
-        self._motor_state_async.set_state(MIT_state.position, MIT_state.velocity, MIT_state.current, MIT_state.temperature, MIT_state.error, acceleration)
+        self._motor_state_async.set_state(MIT_state.position, MIT_state.velocity, self.TMotor_current_to_qaxis_current(MIT_state.current), MIT_state.temperature, MIT_state.error, acceleration)
+        
         self._updated = True
 
     # this method is called by the user to synchronize the current state used by the controller
@@ -184,7 +192,7 @@ class TMotorManager():
 
         # artificially extending the range of the position, current, and velocity that we track
         P_max = MIT_Params[self.type]['P_max']+ 0.01
-        I_max =  MIT_Params[self.type]['T_max']/(MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor']/MIT_Params[self.type]['Current_Factor']) + 0.01
+        I_max =  self.TMotor_current_to_qaxis_current(MIT_Params[self.type]['T_max']) + 0.05
         V_max =  MIT_Params[self.type]['V_max']+ 0.01
 
         if self._old_pos is None:
@@ -244,11 +252,11 @@ class TMotorManager():
         doesn't account for friction losses.
         """
         if self._control_state == _TMotorManState.FULL_STATE:
-            self._canman.MIT_controller(self.ID,self.type, self._command.position, self._command.velocity, self._command.kp, self._command.kd, self._command.current*MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor']/MIT_Params[self.type]['Current_Factor'])
+            self._canman.MIT_controller(self.ID,self.type, self._command.position, self._command.velocity, self._command.kp, self._command.kd, self.qaxis_current_to_TMotor_current(self._command.current))
         elif self._control_state == _TMotorManState.IMPEDANCE:
             self._canman.MIT_controller(self.ID,self.type, self._command.position, self._command.velocity, self._command.kp, self._command.kd, 0.0)
         elif self._control_state == _TMotorManState.CURRENT:
-            self._canman.MIT_controller(self.ID, self.type, 0.0, 0.0, 0.0, 0.0, self._command.current*MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor']/MIT_Params[self.type]['Current_Factor'])
+            self._canman.MIT_controller(self.ID, self.type, 0.0, 0.0, 0.0, 0.0, self.qaxis_current_to_TMotor_current(self._command.current))
         elif self._control_state == _TMotorManState.IDLE:
             self._canman.MIT_controller(self.ID,self.type, 0.0, 0.0, 0.0, 0.0, 0.0)
         elif self._control_state == _TMotorManState.SPEED:
